@@ -1,29 +1,43 @@
 # -*- coding: utf-8 -*-
 # @Time    : 2023/11/18 上午12:18
 # @Author  : sudoskys
-# @File    : __init__.py.py
-# @Software: PyCharm
+# @File    : __init__.py
 
 from ._exceptions import (
+    NovelAiError,
+    APIError,
     AuthError,
-    NovelAiError, APIError,
+    ConcurrentGenerationError,
+    SessionHttpError
 )
 from .credential import JwtCredential, LoginCredential, ApiCredential
 from .sdk import GenerateImageInfer, ImageGenerateResp
+from .sdk import VoiceGenerate, VoiceResponse
+from .sdk import SuggestTags, SuggestTagsResp
 from .sdk import Information, InformationResp
 from .sdk import Login, LoginResp
 from .sdk import Subscription, SubscriptionResp
+from .sdk import Upscale, UpscaleResp
 
 __all__ = [
     "GenerateImageInfer",
     "ImageGenerateResp",
 
+    "VoiceGenerate",
+    "VoiceResponse",
+
+    "Upscale",
+    "UpscaleResp",
+
     "Subscription",
     "SubscriptionResp",
 
     "Login",
     "LoginResp",
 
+    "SuggestTags",
+    "SuggestTagsResp",
+
     "Information",
     "InformationResp",
 
@@ -32,6 +46,8 @@ __all__ = [
     "ApiCredential",
 
     "APIError",
+    "SessionHttpError",
     "AuthError",
     "NovelAiError",
+    "ConcurrentGenerationError"
 ]
