@@ -7,8 +7,10 @@ from typing import Tuple, List
 
 from pydantic import BaseModel
 
+from ..schema import RespBase
 
-class ImageGenerateResp(BaseModel):
+
+class ImageGenerateResp(RespBase):
     class RequestParams(BaseModel):
         endpoint: str
         raw_request: dict = None
@@ -20,3 +22,12 @@ class ImageGenerateResp(BaseModel):
         if not isinstance(self.meta.raw_request.get("parameters"), dict):
             raise Exception("Resp parameters is not dict")
         return self.meta.raw_request.get("parameters").get(key, default)
+
+
+class SuggestTagsResp(RespBase):
+    class Tag(BaseModel):
+        tag: str
+        count: int
+        confidence: float
+
+    tags: List[Tag] = None
