@@ -4,12 +4,15 @@
 # @File    : _shema.py
 # @Software: PyCharm
 from curl_cffi.requests import AsyncSession
+from fake_useragent import UserAgent
 from pydantic import BaseModel
 
+FAKE_UA = UserAgent()
+
 
 class CredentialBase(BaseModel):
     _session: AsyncSession = None
     """会话"""
 
-    async def get_session(self, timeout: int = 180):
+    async def get_session(self, timeout: int = 180, update_headers: dict = None):
         raise NotImplementedError
