@@ -28,7 +28,7 @@ def test_subscription_without_api_key(mock_subscription):
 
 @patch('src.novelai_python.server.GenerateImageInfer')
 def test_generate_image_without_api_key(mock_generate_image):
-    mock_generate_image.return_value.generate.return_value = {"status": "image generated"}
+    mock_generate_image.return_value.request.return_value = {"status": "image generated"}
     response = client.post("/ai/generate_image")
     assert response.status_code == 403
 
